@@ -1,4 +1,6 @@
 """AlgoSquare Dataset API."""
+from __future__ import annotations
+
 import io
 import time
 import numpy as np
@@ -6,6 +8,8 @@ import pandas as pd
 import requests
 import json
 
+from typing import Optional, Union
+
 from ..base.tabular import is_input_metatype
 from ..base.types import Metatype, is_target_metatype, is_classification_metatype, string_to_metatype
 from ..metrics import get_metric
@@ -26,7 +30,7 @@ class Dataset(ApiObject):
         super().__init__(entry)
 
     @staticmethod
-    def get(dataset_id):
+    def get(dataset_id: str) -> Dataset:
         """
         Gets specific dataset.
         
@@ -45,11 +49,11 @@ class Dataset(ApiObject):
         else:
             raise ValueError('unknown data_format')
 
-    def refresh(self):
+    def refresh(self) -> None:
         """reloads dataset."""
         self.update(api_get(f'api/datasets/{self.dataset_id}'))
 
-    def get_tasks(self):
+    def get_tasks(self) -> list[Task]:
         """
         Gets tasks for dataset.
         
@@ -61,26 +65,24 @@ class Dataset(ApiObject):
 class TabularData(Dataset):
     """Tabular data class."""
     @classmethod
-    def from_csv(cls, input_file, target_file, title = None, input_metatypes = None, target_metatypes = None):
+    def from_csv(cls, input_file: str, target_file: str, **kwargs) -> TabularData:
         """
         Creates tabular data from csv files.
         
         Args:
             input_file: path to input data.
             target_file: path to target data.
-            title: title of dataset.
-            input_metatypes: list of Metatype or path to csv file.
-            target_metatypes: list of Metatype or path to csv file.
+            **kwargs: additional arguments passed to from_df.
 
         Returns:
             TabularData.
         """
         input_df = pd.read_csv(input_file, dtype=str)
         target_df = pd.read_csv(target_file, dtype=str)
-        return cls.from_df(title, input_df, target_df, input_metatypes, target_metatypes)
+        return cls.from_df(input_df, target_df, **kwargs)
 
     @classmethod
-    def from_df(cls, input_df, target_df, title = None, input_metatypes = None, target_metatypes = None, ):
+    def from_df(cls, input_df: pd.DataFrame, target_df: pd.DataFrame, title: Optional[str] = None, input_metatypes: Optional[Union[list[Metatype], str]] = None, target_metatypes: Optional[Union[list[Metatype], str]] = None) -> TabularData:
         """
         Creates tabular data from DataFrames.
         
@@ -134,7 +136,7 @@ class TabularData(Dataset):
         entry = api_post('api/datasets', json=dict(settings = settings, files = files, metatypes = metatypes))
         return cls(entry)
 
-    def create_task(self, title = None, metric_name = None, pos_label = None, holdout = 25, input_columns = None, target_columns = None):
+    def create_task(self, title: Optional[str] = None, metric_name: Optional[str] = None, pos_label: Optional[Union[str,int]] = None, holdout: int = 25, input_columns: Optional[list[str]] = None, target_columns: Optional[list[str]] = None) -> Task:
         """
         Creates a task for dataset.
         
