@@ -1,11 +1,13 @@
 """Metric base class."""
 from abc import ABC, abstractmethod
-from .types import Metatype, is_target_metatype
+from typing import Any, Optional, Union
+
+from .types import Metatype, PredictionMethod, is_target_metatype
 
 class Metric(ABC):
     """Base class for all Metrics."""
     @abstractmethod 
-    def __init__(self, name, metatypes, prediction_method, greater_is_better):
+    def __init__(self, name: str, metatypes: Union[Metatype, set[Metatype]], prediction_method: PredictionMethod, greater_is_better: bool):
         """
         Metric base class.
 
@@ -29,18 +31,18 @@ class Metric(ABC):
             if not is_target_metatype(metatype, strict = True):
                 raise ValueError('metatypes must be a set of Metatypes')
 
-        if prediction_method not in ('predict', 'predict_proba', 'decision_function'):
-            raise ValueError('invalid prediction_method')
+        if not isinstance(prediction_method, PredictionMethod):
+            raise TypeError('prediction_method must be a PredictionMethod')
 
-        if Metatype.NUMERICAL in metatypes and prediction_method != 'predict':
+        if Metatype.NUMERICAL in metatypes and prediction_method != PredictionMethod.PREDICT:
             raise ValueError('prediction_method must be predict for numreical-metatype')
 
         self._metatypes = metatypes
-        self._prediction_method = prediction_method
+        self._prediction_method = prediction_method.name.lower()
         self._sign = -1 if greater_is_better else 1
 
     @abstractmethod
-    def score(self, y, pred):
+    def score(self, y: Any, pred: Any) -> float:
         """
         Invokes underlying score function.
 
@@ -57,11 +59,11 @@ class Metric(ABC):
         """Name of Metric."""
         return self._name
 
-    def to_dict(self):
+    def to_dict(self) -> dict:
         metatypes = [metatype.name.lower() for metatype in self._metatypes]
         return dict(name = self._name, prediction_method = self._prediction_method, sign = self._sign, metatypes = metatypes)
 
-    def loss(self, y, pred):
+    def loss(self, y: Any, pred: Any) -> float:
         """
         Loss based on underlying score function where lower is better.
 
@@ -74,7 +76,7 @@ class Metric(ABC):
         """
         return self.score_to_loss(self.score(y, pred))
 
-    def score_to_loss(self, score):
+    def score_to_loss(self, score: float) -> float:
         """
         Converts score to loss.
 
@@ -86,7 +88,7 @@ class Metric(ABC):
         """
         return self._sign * score
 
-    def prediction_score(self, model, X, y):
+    def prediction_score(self, model: Any, X: Any, y: Any) -> float:
         """
         Combined prediction and scoring.
 
@@ -100,7 +102,7 @@ class Metric(ABC):
         """
         return self.score(y, self.prediction(model, X))
 
-    def prediction_loss(self, model, X, y):
+    def prediction_loss(self, model: Any, X: Any, y: Any) -> float:
         """
         Combined prediction and loss.
 
@@ -114,7 +116,7 @@ class Metric(ABC):
         """
         return self.loss(y, self.prediction(model, X))
 
-    def prediction(self, model, *args, **kwargs):
+    def prediction(self, model: Any, *args, **kwargs) -> Any:
         """
         Returns prediction of model.
 
@@ -128,7 +130,7 @@ class Metric(ABC):
         """
         return getattr(model, self._prediction_method)(*args, **kwargs)
 
-    def supports_metatype(self, metatype):
+    def supports_metatype(self, metatype: Metatype) -> bool:
         """
         Checks if metric supports a given metatype.
 
