@@ -1,11 +1,13 @@
 """Predictor base class."""
+from __future__ import annotations
+
 from abc import ABC, abstractmethod
 
 class Predictor(ABC):
     """Base class for all predictors."""
     @classmethod
     @abstractmethod
-    def load(cls, filename):
+    def load(cls, filename: str) -> Predictor:
         """
         Loads a model.
 
@@ -13,12 +15,12 @@ class Predictor(ABC):
             filename: string.
 
         Returns:
-            Model.
+            Predictor subclass.
         """
         pass
 
     @abstractmethod
-    def save(self, filename):
+    def save(self, filename: str) -> None:
         """
         Saves model to file.
 
