@@ -7,14 +7,16 @@ import numpy as np
 import pandas as pd
 import datetime
 
+from typing import Union
+
 from .errors import TestError
 from .targets import create_classification_target, create_regression_target
-from ..base.tabular import TabularClassificationAutoML, TabularRegressionAutoML, TabularClassifier, TabularRegressor, is_input_metatype, extract_statics
+from ..base.tabular import TabularClassificationAlgo, TabularRegressionAlgo, TabularClassifier, TabularRegressor, is_input_metatype, extract_tabular_statics
 from ..base.types import Metatype, is_classification_metatype, is_delimiter_metatype, get_delimiter
 from ..base.errors import ValidationError
 from ..metrics.metrics import get_metric
 
-def create_tabular_inputs(input_metatypes, n_rows = 1000, n_cols = 2, seed = 0):
+def create_tabular_inputs(input_metatypes: set[Metatype], n_rows: int = 1000, n_cols: int = 2, seed: int = 0) -> tuple[pd.DataFrame, list[Metatype]]:
     X_metatypes = []
     data = []
     index = range(n_rows)
@@ -49,7 +51,7 @@ def create_tabular_inputs(input_metatypes, n_rows = 1000, n_cols = 2, seed = 0):
     X.columns = [f'X{i}' for i in range(X.shape[1])]
     return (X.astype(str), X_metatypes)
 
-def load_tabular_data(algo, nan_fraction = 0.1):
+def load_tabular_data(algo: Union[type[TabularClassificationAlgo], type[TabularRegressionAlgo]], nan_fraction: float = 0.1):
     X, X_metatypes = create_tabular_inputs(algo.input_metatypes())
 
     rng = np.random.default_rng(seed = 0)
@@ -61,12 +63,12 @@ def load_tabular_data(algo, nan_fraction = 0.1):
 
     n_cols = 3 if is_multioutput else 1
 
-    if issubclass(algo, TabularClassificationAutoML):
+    if issubclass(algo, TabularClassificationAlgo):
         target_metatype = algo.target_metatype()
         categories = ['bad', 'good'] if target_metatype == Metatype.BINARY else ['red', 'green', 'blue', 'yellow']
         y = create_classification_target(X.index, n_cols, categories)
         y_metatypes = [target_metatype for x in range(n_cols)]
-    elif issubclass(algo, TabularRegressionAutoML):
+    elif issubclass(algo, TabularRegressionAlgo):
         y = create_regression_target(X.index, n_cols)
         y_metatypes = [Metatype.NUMERICAL for x in range(n_cols)]
     else:
@@ -74,12 +76,12 @@ def load_tabular_data(algo, nan_fraction = 0.1):
 
     return (X, y, X_metatypes, y_metatypes)
 
-def test_tabular_algo(algo, output_dir, timeout, nan_fraction):
+def test_tabular_algo(algo_class: Union[type[TabularClassificationAlgo], type[TabularRegressionAlgo]], output_dir: str, timeout: int, nan_fraction: float) -> None:
     """
     Tests tabular algo.
     
     Args:
-        algo: TabularClassificationAutoML or TabularRegressionAutoML.
+        algo_class: subclass of TabularClassificationAlgo or TabularRegressionAlgo.
         output_dir: path for temp files.   
         timeout: training time in seconds.
         nan_fraction: fraction of missing observations in inputs.
@@ -87,19 +89,19 @@ def test_tabular_algo(algo, output_dir, timeout, nan_fraction):
     Raises:
         TypeError, TestError
     """
-    if not (issubclass(algo, TabularClassificationAutoML) or issubclass(algo, TabularRegressionAutoML)):
+    if not (issubclass(algo_class, TabularClassificationAlgo) or issubclass(algo_class, TabularRegressionAlgo)):
         raise TypeError('invalid algo class')
 
-    statics = extract_statics(algo)
+    extract_tabular_statics(algo_class)
 
-    if issubclass(algo, TabularClassificationAutoML):
+    if issubclass(algo_class, TabularClassificationAlgo):
         metric = get_metric('accuracy')
     else:
         metric = get_metric('mean_squared_error')
 
-    X, y, X_metatypes, y_metatypes = load_tabular_data(algo, nan_fraction)
+    X, y, X_metatypes, y_metatypes = load_tabular_data(algo_class, nan_fraction)
 
-    model = algo()
+    model = algo_class()
 
     t_start = time.time()
     model.fit(timeout, metric, X, y, X_metatypes, y_metatypes, X_unlabelled = X)
@@ -110,14 +112,14 @@ def test_tabular_algo(algo, output_dir, timeout, nan_fraction):
 
     print(f'Elapsed time: {fit_seconds}, timeout: {timeout}')
 
-    test_tabular_predictor(model, output_dir, X, y)
+    test_tabular_model(model, output_dir, X, y)
 
-def test_tabular_predictor(predictor, output_dir, X, y):
+def test_tabular_model(model: Union[TabularClassifier, TabularRegressor], output_dir: str, X: pd.DataFrame, y: pd.DataFrame) -> None:
     """
-    Tests tabular predictor.
+    Tests tabular model.
     
     Args:
-        predictor: TabularClassifier or TabularRegressor.
+        model: TabularClassifier or TabularRegressor.
         output_dir: path for temp files.   
         X: DataFrame.
         y: DataFrame.
@@ -125,8 +127,8 @@ def test_tabular_predictor(predictor, output_dir, X, y):
     Raises:
         TypeError, TestError
     """
-    if not (isinstance(predictor, TabularClassifier) or isinstance(predictor, TabularRegressor)):
-        raise TypeError('invalid predictor')
+    if not (isinstance(model, TabularClassifier) or isinstance(model, TabularRegressor)):
+        raise TypeError('invalid model')
 
     if not isinstance(X, pd.DataFrame):
         raise TypeError('X must be a DataFrame')
@@ -134,7 +136,7 @@ def test_tabular_predictor(predictor, output_dir, X, y):
     if not isinstance(y, pd.DataFrame):
         raise TypeError('y must be a DataFrame')
 
-    pred = predictor.predict(X)
+    pred = model.predict(X)
     if not isinstance(pred, pd.DataFrame):
         raise TestError('prediction must be DataFrame')
 
@@ -144,11 +146,11 @@ def test_tabular_predictor(predictor, output_dir, X, y):
     if list(pred.index) != list(X.index):
         raise TestError('prediction index must equal X index')
 
-    if isinstance(predictor, TabularClassifier):
-        prediction_methods = [x.name.lower() for x in predictor.prediction_methods()]
+    if isinstance(model, TabularClassifier):
+        prediction_methods = [x.name.lower() for x in model.prediction_methods()]
         for prediction_method in prediction_methods:
             if prediction_method != 'predict':
-                pred_prediction_method = getattr(predictor, prediction_method)(X)
+                pred_prediction_method = getattr(model, prediction_method)(X)
                 if y.shape[1] == 1:
                     pred_prediction_method = [pred_prediction_method]
 
@@ -157,9 +159,9 @@ def test_tabular_predictor(predictor, output_dir, X, y):
 
     if output_dir is not None:
         filename = os.path.join(output_dir, uuid.uuid4().hex + '.mdl')
-        predictor.save(filename)
+        model.save(filename)
 
-        model_loaded = predictor.load(filename)
+        model_loaded = model.load(filename)
         pred_loaded = model_loaded.predict(X)
 
         if not pred_loaded.equals(pred):
@@ -167,7 +169,7 @@ def test_tabular_predictor(predictor, output_dir, X, y):
 
         os.remove(filename)
 
-    print(f'TESTING DONE: {type(predictor).__name__}')
+    print(f'TESTING DONE: {type(model).__name__}')
 
 
 def _check_prediction(prediction_method, ppm, X, y, pred):
